@@ -80,7 +80,8 @@ def _get_poolname_of_path(path):
     while str(path).endswith("/"):
         path = Path(str(path[:-1]))
     if Path(path).exists():
-        dfout = subprocess.check_output(["df", "-T", path], encoding="utf8").splitlines()[1]
+        df = search_env_path("df")
+        dfout = subprocess.check_output([df, "-T", path], encoding="utf8").splitlines()[1]
     else:
         return None
     fullpath, fstype, _, _, _, _, df_path = unify(dfout.strip()).split(" ")
